==> XIV_host_attach-1.1-suse-11-x64.tar.gz: opt/xiv/host_attach/lib/python/hostattachment/platform/classes.py <==
#-------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2009
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
#
#-------------------------------------------------------------------------------------------------

import platform
import re
import logging

from hostattachment.exceptions import HostAttachmentError
from hostattachment.classes import FCPort
from fc.fc_hosts import FiberChannelHosts
from iscsi import Iscsi
from kernel_module import KernelModule

from multipath.classes import MultipathConfiguration

def _get_suse_patchlevel():
  patchlevel = 0
  suse_release_file = file("/etc/SuSE-release")
  regexp = re.compile("^PATCHLEVEL\s*=\s*(\d+)$")
  for line in suse_release_file.readlines():
    match = regexp.search(line)
    if match is not None:
      patchlevel = match.groups()[0]
      break
  suse_release_file.close()

  return patchlevel

def check_os_and_version():
  supported = False

  if platform.system() != "Linux":
    raise HostAttachmentError(\
      "This host attachment is for the Linux operating system only.")
  dist = platform.dist()
  version = float(dist[1])
  if (dist[0] == "redhat"): # this one includes Oracle!
    if (int(version) == 4):
      minor_version = int(dist[2][len(dist[2])-1])
      if (minor_version >= 5): # 4.5 and above
        supported = True
    if (int(version) == 5) and version >= 5.1: # 5.1 and above
      supported = True

  if (dist[0] == "SuSE"):
    if (int(version) == 10):
      if _get_suse_patchlevel() >= 2:
        supported = True

    elif (int(version) == 11):
      supported = True

  if not supported:
    raise HostAttachmentError("This Linux version is not supported.")

class Attachment(object):
  def __init__(self, uname, backup_path = "/var/tmp"):
    check_os_and_version()
    self.multipath_configuration = MultipathConfiguration(backup_path)
    self.iscsi = Iscsi(backup_path)

  def is_platform_officially_supported(self):
    """
    Verify if platform is officially supported.
    Returns True if supported, False if not supported, but HAK can configure it
    Raises a HostAttachmentError on invalid or unknown platforms or any other error
    """
    # We return true always, cuz we trust the rpm's prerequisites
    return True

  def config(self):
    """
    Perform the host storage and multipath configuration
    """
    logging.info("Going to configure mulipathing")
    self.multipath_configuration.configure_multipath()
    logging.info("Going to configure iscsi")
    self.iscsi.configure()
 
  def verify(self):
    logging.info("Going to verify platform configuration")
    is_configured_mp = self.multipath_configuration.is_multipath_configured()
    is_configured_iscsi = self.iscsi.is_configured()
    return is_configured_mp and is_configured_iscsi

  def config_tasks(self):
    logging.info("Getting platform configuration tasks")
    task_list = self.multipath_configuration.get_configuration_task_list()
    task_list_iscsi = self.iscsi.get_configuration_task_list()

    task_list.extend(task_list_iscsi)

    return task_list


class ISCSIAttachment(Attachment):
  def get_storage_ports(self):
    retval = (self.iscsi.get_iqn(), "-")
    if (retval[0] is None):
      retval = ("iSCSI IQN not configured", retval[1])

    return retval

  def rescan(self):
    self.iscsi.scan()
    self.multipath_configuration.update_maps()

  def connect_iscsi(self, discovery_address):
    self.iscsi.connect(discovery_address)
 
  def disconnect_iscsi(self, discovery_address):
    self.iscsi.disconnect(discovery_address)

class FCAttachment(Attachment):
  def get_storage_ports(self):
    fc_hosts = FiberChannelHosts()
    fc_ports = []
    scsi_hosts = fc_hosts.get_scsi_hosts()
    for scsi_host in scsi_hosts:
      fc_ports.append(FCPort(scsi_host.wwn, scsi_host.type, "N/A"))

    return fc_ports

  def rescan(self):
    fc_hosts = FiberChannelHosts()
    sg_kernel_module = KernelModule('sg')
    if not sg_kernel_module.insert_module():
      logging.warning('kernel module sg does not exist,'+\
        'will not remove failed or removed devices')
    logging.info('rescanning FC for devices, this may take a while...')
    fc_hosts.scan_all_hosts()

==> XIV_host_attach-1.1.1-suse-11-x64.tar.gz: opt/xiv/host_attach/lib/python/hostattachment/platform/classes.py <==
#-------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2009
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
#
#-------------------------------------------------------------------------------------------------

import platform
import re
import logging

from hostattachment.exceptions import HostAttachmentError
from hostattachment.classes import FCPort
from fc.fc_hosts import FiberChannelHosts
from iscsi import detect_iscsi_method
from kernel_module import KernelModule

def _get_suse_patchlevel():
  patchlevel = 0
  suse_release_file = file("/etc/SuSE-release")
  regexp = re.compile("^PATCHLEVEL\s*=\s*(\d+)$")
  for line in suse_release_file.readlines():
    match = regexp.search(line)
    if match is not None:
      patchlevel = match.groups()[0]
      break
  suse_release_file.close()

  return patchlevel

def check_os_and_version():
  supported = False

  if platform.system() != "Linux":
    raise HostAttachmentError(\
      "This host attachment is for the Linux operating system only.")
  dist = platform.dist()
  version = float(dist[1])
  if (dist[0] == "redhat"): # this one includes Oracle!
    if (int(version) == 4):
      minor_version = int(dist[2][len(dist[2])-1])
      if (minor_version >= 5): # 4.5 and above
        supported = True
    if (int(version) == 5) and version >= 5.1: # 5.1 and above
      supported = True

  if (dist[0] == "SuSE"):
    if (int(version) == 10):
      if _get_suse_patchlevel() >= 2:
        supported = True

    elif (int(version) == 11):
      supported = True

  if not supported:
    raise HostAttachmentError("This Linux version is not supported. " + \
        "Please refer to the Release Notes of XIV Host Attachment Kit.")

def get_os_string():
    """Returns os + version strings such as redhat4 or SuSE10"""
    dist = platform.dist()
    name = dist[0]

    # Get most significant number of the version
    match = re.compile("^(\d+)").search(dist[1])
    if match is None:
        raise HostAttachmentError("Unrecognized OS version string '%s'" % dist[1])

    version = match.groups()[0]

    ret_str = "%s%s" % (name, version)

    return ret_str

class Attachment(object):
  def __init__(self, uname, backup_path = "/var/tmp"):
    from multipath.classes import MultipathConfiguration

    check_os_and_version()
    self.multipath_configuration = MultipathConfiguration(backup_path)
    self.iscsi = detect_iscsi_method(backup_path)

  def is_platform_officially_supported(self):
    """
    Verify if platform is officially supported.
    Returns True if supported, False if not supported, but HAK can configure it
    Raises a HostAttachmentError on invalid or unknown platforms or any other error
    """
    # We return true always, cuz we trust the rpm's prerequisites
    return True

  def config(self):
    """
    Perform the host storage and multipath configuration
    """
    logging.info("Going to configure mulipathing")
    self.multipath_configuration.configure_multipath()
    logging.info("Going to configure iscsi")
    self.iscsi.configure()
 
  def verify(self):
    logging.info("Going to verify platform configuration")
    is_configured_mp = self.multipath_configuration.is_multipath_configured()
    is_configured_iscsi = self.iscsi.is_configured()
    return is_configured_mp and is_configured_iscsi

  def config_tasks(self):
    logging.info("Getting platform configuration tasks")
    task_list = self.multipath_configuration.get_configuration_task_list()
    task_list_iscsi = self.iscsi.get_configuration_task_list()

    task_list.extend(task_list_iscsi)

    return task_list


class ISCSIAttachment(Attachment):
  def get_storage_ports(self):
    retval = (self.iscsi.get_iqn(), "-")
    if (retval[0] is None):
      retval = ("iSCSI IQN not configured", retval[1])

    return retval

  def rescan(self):
    self.iscsi.scan()
    self.multipath_configuration.update_maps()

  def connect_iscsi(self, discovery_address):
    self.iscsi.connect(discovery_address)
 
  def disconnect_iscsi(self, discovery_address):
    self.iscsi.disconnect(discovery_address)

class FCAttachment(Attachment):
  def get_storage_ports(self):
    fc_hosts = FiberChannelHosts()
    fc_ports = []
    scsi_hosts = fc_hosts.get_scsi_hosts()
    for scsi_host in scsi_hosts:
      fc_ports.append(FCPort(scsi_host.wwn, scsi_host.type, "N/A"))

    return fc_ports

  def rescan(self):
    fc_hosts = FiberChannelHosts()
    sg_kernel_module = KernelModule('sg')
    if not sg_kernel_module.insert_module():
      logging.warning('kernel module sg does not exist,'+\
        'will not remove failed or removed devices')
    logging.info('rescanning FC for devices, this may take a while...')
    fc_hosts.scan_all_hosts()
    self.multipath_configuration.update_maps()
